import {defineStore} from 'pinia'
import axios from "axios";
import {useConfigStore} from "./config";

export const useUserStore = defineStore('user', {
    persist: true,
    state: () => ({
        refresh_token: null as null | string,
        jwt_token: null as null | string,
    }),
    getters: {
        isLoggedIn(): boolean {
            return this.jwt_token !== null
        }
    },
    actions: {
        login(refresh_token: string, jwt_token: string) {
            this.refresh_token = refresh_token
            this.jwt_token = jwt_token
        },
        logout() {
            console.log("logout")
            this.refresh_token = null
            this.jwt_token = null
        },
        refresh() {
            let config = useConfigStore()

            axios.post(config.getRefreshUrl(), {
                refresh_token: this.refresh_token
            }).then(r => {
                this.jwt_token = r.data.token
            }).catch(e => {
                console.error(e)
                this.logout()
            })
        }
    }
})